==> vizent-1.0-py3-none-any.whl: vizent/metofficelimits.py <==
# Definitions for scales
metOfficeLimits = [ -30, -28, -26, -24, 
                    -22, -20, -18, -16, 
                    -14, -12, -10, -8, 
                    -6, -4, -2, 0,
                     2, 4, 6, 8, 
                     10, 12, 14, 16, 
                     18 , 20, 22, 24, 
                     26, 28, 30, 32, 
                     34, 36 ]

metOfficeColours = [(0.0, 0.01568627450980392, 0.07450980392156863), 
                    (0.0, 0.03529411764705882, 0.1450980392156863), 
                    (0.0, 0.027450980392156862, 0.20784313725490197), 
                    (0.0, 0.0784313725490196, 0.3058823529411765), 
                    (0.0, 0.10196078431372549, 0.3843137254901961), 
                    (0.023529411764705882, 0.12941176470588237, 0.4549019607843137), 
                    (0.12156862745098039, 0.21568627450980393, 0.5058823529411764), 
                    (0.20784313725490197, 0.2980392156862745, 0.5529411764705883), 
                    (0.30196078431372547, 0.3803921568627451, 0.6078431372549019), 
                    (0.41568627450980394, 0.47843137254901963, 0.6705882352941176), 
                    (0.5058823529411764, 0.5607843137254902, 0.7215686274509804), 
                    (0.6078431372549019, 0.6470588235294118, 0.7764705882352941), 
                    (0.6980392156862745, 0.7254901960784313, 0.8274509803921568), 
                    (0.7803921568627451, 0.803921568627451, 0.8745098039215686), 
                    (0.8666666666666667, 0.8823529411764706, 0.9254901960784314), 
                    (0.9529411764705882, 0.9568627450980393, 0.9725490196078431), 
                    (0.996078431372549, 0.9568627450980393, 0.8509803921568627), 
                    (0.9921568627450981, 0.9254901960784314, 0.7294117647058823), 
                    (0.996078431372549, 0.8980392156862745, 0.615686274509804), 
                    (0.996078431372549, 0.8705882352941177, 0.5019607843137255), 
                    (0.996078431372549, 0.8392156862745098, 0.4117647058823529), 
                    (0.9921568627450981, 0.8, 0.3843137254901961), 
                    (0.9921568627450981, 0.7647058823529411, 0.3686274509803922), 
                    (0.996078431372549, 0.7254901960784313, 0.3411764705882353), 
                    (0.996078431372549, 0.6862745098039216, 0.3215686274509804), 
                    (0.996078431372549, 0.6470588235294118, 0.29411764705882354), 
                    (0.996078431372549, 0.6078431372549019, 0.2784313725490196), 
                    (0.9921568627450981, 0.5686274509803921, 0.24705882352941178), 
                    (0.996078431372549, 0.5254901960784314, 0.22745098039215686), 
                    (0.9725490196078431, 0.4627450980392157, 0.21568627450980393), 
                    (0.9490196078431372, 0.4, 0.2196078431372549), 
                    (0.9176470588235294, 0.3215686274509804, 0.21568627450980393), 
                    (0.8901960784313725, 0.24705882352941178, 0.2196078431372549), 
                    (0.8549019607843137, 0.16470588235294117, 0.2196078431372549)]

==> vizent-1.1.0b1-py3-none-any.whl: vizent/metofficelimits.py <==
# Definitions for scales
metOfficeLimits = [ -30, -28, -26, -24, 
                    -22, -20, -18, -16, 
                    -14, -12, -10, -8, 
                    -6, -4, -2, 0,
                     2, 4, 6, 8, 
                     10, 12, 14, 16, 
                     18 , 20, 22, 24, 
                     26, 28, 30, 32, 
                     34, 36 ]

metOfficecolors = [(0.0, 0.01568627450980392, 0.07450980392156863), 
                    (0.0, 0.03529411764705882, 0.1450980392156863), 
                    (0.0, 0.027450980392156862, 0.20784313725490197), 
                    (0.0, 0.0784313725490196, 0.3058823529411765), 
                    (0.0, 0.10196078431372549, 0.3843137254901961), 
                    (0.023529411764705882, 0.12941176470588237, 0.4549019607843137), 
                    (0.12156862745098039, 0.21568627450980393, 0.5058823529411764), 
                    (0.20784313725490197, 0.2980392156862745, 0.5529411764705883), 
                    (0.30196078431372547, 0.3803921568627451, 0.6078431372549019), 
                    (0.41568627450980394, 0.47843137254901963, 0.6705882352941176), 
                    (0.5058823529411764, 0.5607843137254902, 0.7215686274509804), 
                    (0.6078431372549019, 0.6470588235294118, 0.7764705882352941), 
                    (0.6980392156862745, 0.7254901960784313, 0.8274509803921568), 
                    (0.7803921568627451, 0.803921568627451, 0.8745098039215686), 
                    (0.8666666666666667, 0.8823529411764706, 0.9254901960784314), 
                    (0.9529411764705882, 0.9568627450980393, 0.9725490196078431), 
                    (0.996078431372549, 0.9568627450980393, 0.8509803921568627), 
                    (0.9921568627450981, 0.9254901960784314, 0.7294117647058823), 
                    (0.996078431372549, 0.8980392156862745, 0.615686274509804), 
                    (0.996078431372549, 0.8705882352941177, 0.5019607843137255), 
                    (0.996078431372549, 0.8392156862745098, 0.4117647058823529), 
                    (0.9921568627450981, 0.8, 0.3843137254901961), 
                    (0.9921568627450981, 0.7647058823529411, 0.3686274509803922), 
                    (0.996078431372549, 0.7254901960784313, 0.3411764705882353), 
                    (0.996078431372549, 0.6862745098039216, 0.3215686274509804), 
                    (0.996078431372549, 0.6470588235294118, 0.29411764705882354), 
                    (0.996078431372549, 0.6078431372549019, 0.2784313725490196), 
                    (0.9921568627450981, 0.5686274509803921, 0.24705882352941178), 
                    (0.996078431372549, 0.5254901960784314, 0.22745098039215686), 
                    (0.9725490196078431, 0.4627450980392157, 0.21568627450980393), 
                    (0.9490196078431372, 0.4, 0.2196078431372549), 
                    (0.9176470588235294, 0.3215686274509804, 0.21568627450980393), 
                    (0.8901960784313725, 0.24705882352941178, 0.2196078431372549), 
                    (0.8549019607843137, 0.16470588235294117, 0.2196078431372549)]
